# eric7.UI.DeleteFilesConfirmationDialog

Module implementing a dialog to confirm deletion of multiple files.

### Global Attributes

None

### Classes

DeleteFilesConfirmationDialog | Class implementing a dialog to confirm deletion of multiple files.

### Functions

None

## DeleteFilesConfirmationDialog

Class implementing a dialog to confirm deletion of multiple files.

### Derived from

QDialog, Ui_DeleteFilesConfirmationDialog

### Class Attributes

None

### Class Methods

None

### Methods

DeleteFilesConfirmationDialog | Constructor
on_buttonBox_clicked | Private slot called by a button of the button box clicked.

### Static Methods

None

#### DeleteFilesConfirmationDialog (Constructor)

DeleteFilesConfirmationDialog(parent, caption, message, files)

Constructor

parent
  parent of this dialog (QWidget)
caption
  window title for the dialog (string)
message
  message to be shown (string)
files
  list of filenames to be shown (list of strings)

#### DeleteFilesConfirmationDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

Up